
# Slot: mixins


List of definitions to be mixed in. Targets may be any definition of the same type

URI: [linkml:slot_definition_mixins](https://w3id.org/linkml/slot_definition_mixins)


## Domain and Range

slot_definition &#8594;  <sub>0..\*</sub> slot_definition

## Parents

 *  is_a: mixins

## Children


## Used by

 * slot_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | traits |
| **Comments:** | | mixins act in the same way as parents (is_a). They allow a model to have a primary strict hierachy, while keeping the benefits of multiple inheritance |
| **See also:** | | [https://en.wikipedia.org/wiki/Mixin](https://en.wikipedia.org/wiki/Mixin) |

